Module common

Module common 

Enums

ScalarChunkIterator
Helper type similar to itertools::Either, but with 3 variants.

Constants

LEROBOT_DATASET_IGNORED_COLUMNS
Columns in the LeRobot dataset schema that we do not visualize in the viewer, and thus ignore.

Traits

LeRobotDataset
Shared interface for all LeRobot dataset versions.

Functions

load_and_stream_common
Shared streaming loop for LeRobot dataset versions.
load_and_stream_versioned
Prepare store info for all episodes and stream them using the provided loader.
load_episode_depth_images
load_episode_images
load_scalar
prepare_episode_chunks
Send SetStoreInfo messages for each episode and return the associated store ids.