pub struct Names(/* private fields */);Expand description
Name metadata for a feature in the LeRobot dataset.
The name metadata can consist of
- A flat list of names for each dimension of a feature (e.g.,
["height", "width", "channel"]). - A nested list of names for each dimension of a feature (e.g.,
[[""kLeftShoulderPitch", "kLeftShoulderRoll"]]) - A map with a string array value (e.g.,
{ "motors": ["motor_0", "motor_1", …] }or{ "axes": ["x", "y", "z"] }).
Implementations