pub struct McapLoader { /* private fields */ }Expand description
A DataLoader for MCAP files.
There are many different ways to extract and interpret information from MCAP files.
For example, it might be interesting to query for particular fields of messages,
or show information directly in the Rerun viewer. Because use-cases can vary, the
McapLoader is made up of re_mcap::Layers, each representing different views of the
underlying data.
These layers can be specified in the CLI wen converting an MCAP file to an .rrd. Here are a few examples:
Optionally, Lenses can be configured via Self::with_lenses to transform
chunks as they are loaded (e.g., converting raw protobuf data into semantic Rerun components).
Implementations
Sourceimpl McapLoader
impl McapLoader
Sourcepub fn new(selected_layers: SelectedLayers) -> Self
pub fn new(selected_layers: SelectedLayers) -> Self
Creates a new McapLoader that extracts the specified layers.
Sourcepub fn with_raw_fallback(self, raw_fallback_enabled: bool) -> Self
pub fn with_raw_fallback(self, raw_fallback_enabled: bool) -> Self
Configures whether the raw layer is used as a fallback for unsupported channels.
Sourcepub fn with_lenses(self, lenses: Lenses) -> Self
pub fn with_lenses(self, lenses: Lenses) -> Self
Configures lenses to apply to chunks as they are loaded.